@@ -12,7 +12,7 @@ find.clusters.data.frame <- function(x, clust = NULL, n.pca = NULL, n.clust = NU
                                      criterion = c("diffNgroup", "min", "goesup",
                                                    "smoothNgoesup", "goodfit"),
                                      max.n.clust = round(nrow(x)/10), n.iter = 1e5,
-                                     n.start = 10, center = TRUE, scale = TRUE,
+                                     n.start = 10, center = TRUE, scale = FALSE,
                                      pca.select = c("nbEig","percVar"),
                                      perc.pca = NULL, ..., dudi = NULL){
 
