@@ -117,7 +117,15 @@ setMethod("tab", signature(x="genpop"), function(x, freq=FALSE, NA.method=c("asi
         out <- x@tab
     } else {
         out <- x@tab
-        f1 <- function(vec) return(vec/sum(vec,na.rm=TRUE))
+        f1 <- function(vec) {
+          sums <- sum(vec, na.rm = TRUE)
+          if (sums == 0) {
+            vec[] <- 0.0
+            return(vec)
+          } else {
+            return(vec/sums)
+          }
+        }
         ## compute frequencies
         fac <- x@loc.fac
         if (is.null(fac)) fac <- rep(1, nLoc(x))
@@ -310,6 +318,22 @@ setGeneric("seppop", function(x, ...) standardGeneric("seppop"))
   kObj
 }
 
+.get_pop_inds <- function(x, pop) {
+
+  if(is.factor(pop)) pop <- as.character(pop)
+  if(!is.character(pop)) pop <- popNames(x)[pop]
+  temp <- !pop %in% pop(x)
+  if (any(temp)) { # if wrong population specified
+    warning(paste("the following specified populations do not exist:", paste0(pop[temp], collapse = ", ")), call. = FALSE)
+    if (all(temp)){
+      warning("no populations selected - ignoring", call. = FALSE)
+      pop <- pop(x)
+    }
+  }
+  
+  pop(x) %in% pop
+}
+
 ## genind
 setMethod(
   f = "seppop", 
